/*
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This code is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this code; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  */

/* Copyright (C) 2000 Ian Zimmerman <itz@speakeasy.org> */

#ifndef INCLUDE_CONNECTIONS_H
#define INCLUDE_CONNECTIONS_H

/* $Id: connections.h,v 1.8 2002/06/04 06:54:22 itz Exp $ */

#include <sys/types.h>

#include "gim_event.h"

enum gim_state {
  gim_state_new,
  gim_state_open,
  gim_state_stopped
};

struct gim_connect_t {
  int allocated;                /* 0 => available */
  uid_t owner;                  /* user id of owning process */
  pid_t pid;                    /* owning process, used to check for stopped state */
  int fd;                       /* file descriptor for client socket */
  int vt;                       /* virt terminal # or 0 for background client */
  unsigned min_mod;             /* minimum modifier mask */
  unsigned max_mod;             /* maximum modifier mask */
  enum gim_event_kind_t handle; /* kinds of events accepted */
  enum gim_event_kind_t pass;   /* kinds of events to pass to root clients */
  enum gim_state state;
  struct gim_connect_t* prev;   /* previous on vt chain */
  struct gim_connect_t* next;   /* next on vt chain */
};

void
add_connection (int fd);

void
set_connection_vt (struct gim_connect_t*, int vt);

void
unset_connection_vt (struct gim_connect_t*);

void
delete_connection (struct gim_connect_t*);

struct gim_connect_t*
get_connection_by_fd (int fd);

struct gim_connect_t*
get_active_connection (int vt, unsigned mods);

#endif /* INCLUDE_CONNECTIONS_H */
